pub enum ChangeKdfError {
MasterPassword(MasterPasswordError),
MissingMasterPasswordUnlockData,
NotAuthenticated(NotAuthenticatedError),
Api(ApiError),
}Expand description
Errors that can occur while changing the account KDF settings.
Variants
MasterPassword(MasterPasswordError)
Deriving the new authentication or unlock data failed.
MissingMasterPasswordUnlockData
The current master-password unlock data is not available in the state bridge.
NotAuthenticated(NotAuthenticatedError)
The client is not authenticated with a master password.
Api(ApiError)
The server rejected the change-KDF request.