pub struct UserCryptoManagementClient {
pub(crate) client: Client,
}Expand description
Client for managing the cryptographic machinery of a user account, including key-rotation.
Fields
client: ClientImplementations
Sourceimpl UserCryptoManagementClient
impl UserCryptoManagementClient
Sourcepub async fn migrate_to_key_connector(
&self,
key_connector_url: String,
) -> Result<(), MigrateToKeyConnectorError>
pub async fn migrate_to_key_connector( &self, key_connector_url: String, ) -> Result<(), MigrateToKeyConnectorError>
Migrates an initialized account to Key Connector unlock.
Requires the client to be unlocked so the current user key is available in memory.
Sourceimpl UserCryptoManagementClient
impl UserCryptoManagementClient
Sourcepub async fn password_change_and_rotate_user_keys(
&self,
request: PasswordChangeAndRotateUserKeysRequest,
) -> Result<(), RotateUserKeysError>
pub async fn password_change_and_rotate_user_keys( &self, request: PasswordChangeAndRotateUserKeysRequest, ) -> Result<(), RotateUserKeysError>
Combines a password change and user key rotation into a single request.
Before rotating, this checks whether the user’s public key encryption key pair needs regeneration and fixes it if necessary. This ensures that key rotation can proceed even if the existing private key is corrupt.
Sourceimpl UserCryptoManagementClient
impl UserCryptoManagementClient
Sourcepub async fn rotate_user_keys(
&self,
request: RotateUserKeysRequest,
) -> Result<(), RotateUserKeysError>
pub async fn rotate_user_keys( &self, request: RotateUserKeysRequest, ) -> Result<(), RotateUserKeysError>
Rotates the user’s encryption keys without a password change.
Sourceimpl UserCryptoManagementClient
impl UserCryptoManagementClient
Sourcepub async fn get_untrusted_organization_public_keys(
&self,
) -> Result<Vec<V1OrganizationMembership>, RotateUserKeysError>
pub async fn get_untrusted_organization_public_keys( &self, ) -> Result<Vec<V1OrganizationMembership>, RotateUserKeysError>
Fetches the organization public keys for V1 organization memberships for the user for organizations for which reset password is enrolled. These have to be trusted manually be the user before rotating.
Sourcepub async fn get_untrusted_emergency_access_public_keys(
&self,
) -> Result<Vec<V1EmergencyAccessMembership>, RotateUserKeysError>
pub async fn get_untrusted_emergency_access_public_keys( &self, ) -> Result<Vec<V1EmergencyAccessMembership>, RotateUserKeysError>
Fetches the emergency access public keys for V1 emergency access memberships for the user. These have to be trusted manually be the user before rotating.
Sourceimpl UserCryptoManagementClient
impl UserCryptoManagementClient
Sourcepub fn pin_settings(&self) -> PinSettingsClient
pub fn pin_settings(&self) -> PinSettingsClient
Returns the PIN settings sub-client.
Sourceimpl UserCryptoManagementClient
impl UserCryptoManagementClient
Sourcepub async fn regenerate_public_key_encryption_key_pair_if_needed(
&self,
) -> Result<bool, KeyPairRegenerationError>
pub async fn regenerate_public_key_encryption_key_pair_if_needed( &self, ) -> Result<bool, KeyPairRegenerationError>
Checks whether the user’s public key encryption key pair needs regeneration, and if so, generates a new key pair and submits it to the server.
If regeneration is performed, the updated [WrappedAccountCryptographicState] is
persisted via the state bridge (when registered).
Requires the client to be unlocked so the current user key is available in memory. Only applicable to V1 encryption accounts.
Sourcepub async fn should_regenerate_public_key_encryption_key_pair(
&self,
) -> Result<bool, KeyPairRegenerationError>
pub async fn should_regenerate_public_key_encryption_key_pair( &self, ) -> Result<bool, KeyPairRegenerationError>
Checks whether the user’s public key encryption key pair needs regeneration.
Returns true if the key pair is missing, corrupt, or doesn’t match the public key on
the server. Returns false if the key pair is valid or if regeneration is not applicable
(e.g., user key not available, V2 encryption account).
Sourcepub(crate) async fn regenerate_public_key_encryption_key_pair_if_needed_with_ciphers(
&self,
ciphers: &[Cipher],
) -> Result<Option<WrappedAccountCryptographicState>, KeyPairRegenerationError>
pub(crate) async fn regenerate_public_key_encryption_key_pair_if_needed_with_ciphers( &self, ciphers: &[Cipher], ) -> Result<Option<WrappedAccountCryptographicState>, KeyPairRegenerationError>
Variant of Self::regenerate_public_key_encryption_key_pair_if_needed that accepts
pre-fetched ciphers instead of fetching them from the API.
Returns None if no regeneration was needed, or the updated
[WrappedAccountCryptographicState] read from the key store after regeneration.